# Edit config.py

You can edit any configuration value by manually editing the `config.py`, located in ToolMate AI directory.

1. Make sure you know what and how to edit.  Invalid entries can break the startup process.  In case anything goes wrong with the file, delete it and restart ToolMate AI.

2. Make sure ToolMate AI app is closed when you manually edit `config.py` with third-party text-editor.  If you want to edit the file while you are running the app, enter `.editconfigs` in ToolMate AI prompt.